summaryrefslogtreecommitdiffstats
path: root/win/tclWinTime.c
diff options
context:
space:
mode:
authorhobbs <hobbs>2001-11-21 02:36:18 (GMT)
committerhobbs <hobbs>2001-11-21 02:36:18 (GMT)
commitcff9c3309b2e3c096c301a94bff0d9804be13520 (patch)
treed6c9734d5b8944f4d96bc77057fc560b661f57c4 /win/tclWinTime.c
parentf59ffab94e11d0dc9efd7189ec5c64e904cdfedd (diff)
downloadtcl-cff9c3309b2e3c096c301a94bff0d9804be13520.zip
tcl-cff9c3309b2e3c096c301a94bff0d9804be13520.tar.gz
tcl-cff9c3309b2e3c096c301a94bff0d9804be13520.tar.bz2
added TIP#73 patch #483500 from Kevin Kenny.
This deprecates TclpGetTime in favor of new Tcl_GetTime.
Diffstat (limited to 'win/tclWinTime.c')
-rw-r--r--win/tclWinTime.c12
1 files changed, 6 insertions, 6 deletions
diff --git a/win/tclWinTime.c b/win/tclWinTime.c
index d12afdf..d90e8ba 100644
--- a/win/tclWinTime.c
+++ b/win/tclWinTime.c
@@ -9,7 +9,7 @@
* See the file "license.terms" for information on usage and redistribution
* of this file, and for a DISCLAIMER OF ALL WARRANTIES.
*
- * RCS: @(#) $Id: tclWinTime.c,v 1.8 2001/09/06 11:48:44 davygrvy Exp $
+ * RCS: @(#) $Id: tclWinTime.c,v 1.9 2001/11/21 02:36:21 hobbs Exp $
*/
#include "tclWinInt.h"
@@ -131,7 +131,7 @@ unsigned long
TclpGetSeconds()
{
Tcl_Time t;
- TclpGetTime( &t );
+ Tcl_GetTime( &t );
return t.sec;
}
@@ -159,14 +159,14 @@ unsigned long
TclpGetClicks()
{
/*
* Use the TclpGetTime abstraction to get the time in microseconds,
* as nearly as we can, and return it.
*/
Tcl_Time now; /* Current Tcl time */
unsigned long retval; /* Value to return */
- TclpGetTime( &now );
+ Tcl_GetTime( &now );
retval = ( now.sec * 1000000 ) + now.usec;
return retval;
@@ -205,7 +205,7 @@ TclpGetTimeZone (currentTime)
/*
*----------------------------------------------------------------------
*
- * TclpGetTime --
+ * Tcl_GetTime --
*
* Gets the current system time in seconds and microseconds
* since the beginning of the epoch: 00:00 UCT, January 1, 1970.
@@ -226,7 +226,7 @@ TclpGetTimeZone (currentTime)
*/
void
-TclpGetTime(timePtr)
+Tcl_GetTime(timePtr)
Tcl_Time *timePtr; /* Location to store time information. */
{
@@ -159,14 +159,14 @@ unsigned long
{
/*
- * Use the TclpGetTime abstraction to get the time in microseconds,
+ * Use the Tcl_GetTime abstraction to get the time in microseconds,
* as nearly as we can, and return it.
*/